/*
 *  shortcuts.h	
 *
 *  Written by:		Ullrich Hafner
 *  
 *  Copyright (C) 1998 Ullrich Hafner <hafner@bigfoot.de>
 */

/*
 *  $Date: 1999/03/03 11:29:35 $
 *  $Author: hafner $
 *  $Revision: 1.2 $
 *  $State: Exp $
 */

#ifndef _SHORTCUTS_H
#define _SHORTCUTS_H

#include <gtk/gtk.h>
#include "proplist_t.h"

void
add_shortcut (GtkWidget *page, proplist_t key);

#endif /* not _SHORTCUTS_H */
